{% extends "admin/base_site.html" %}
{% load i18n admin_urls admin_static admin_modify %}
{% load url from future %}

{% block extrahead %}{{ block.super }}
<script type="text/javascript" src="{% url 'admin:jsi18n' %}"></script>
{{ media }}
<script src="/static/liver/jwplayer_6_11/jwplayer.js"></script>
<script>jwplayer.key="{{ server.jwplayer_key }}"</script>

{% endblock %}

{% block extrastyle %}{{ block.super }}<link rel="stylesheet" type="text/css" href="{% static "admin/css/forms.css" %}" />{% endblock %}

{% block coltype %}colM{% endblock %}

{% block bodyclass %}{{ opts.app_label }}-{{ opts.object_name.lower }} change-form{% endblock %}

{% if not is_popup %}
{% block breadcrumbs %}
<div class="breadcrumbs">
</div>
{% endblock %}
{% endif %}

{% block content %}<div id="content-main">


<div id='player'></div>

<script type='text/javascript'>

    media='{{ recording.get_smil }}';
    token='{{ server.token }}';
    prefix='{{ server.prefix }}';

    jwplayer('player').setup({
file:  prefix + '/' + media + '/playlist.m3u8?audioindex=0&t=' + token,
        type: 'hls',
        primary: 'flash',
        width: '100%',
        height: '500',
        // autostart: true
    });



</script>




{% endblock %}
